summaryrefslogtreecommitdiffstats
path: root/src/part/radialMap/widget.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:55:44 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:55:44 -0600
commit9b21afd056f51a1dba015292a5472a146de967bd (patch)
tree0c642c457dea43eb9af17b865bad4dbc43f9fc57 /src/part/radialMap/widget.cpp
parent5f20b2e679037af4b18ac901bdf78a08e5c0da39 (diff)
downloadfilelight-9b21afd056f51a1dba015292a5472a146de967bd.tar.gz
filelight-9b21afd056f51a1dba015292a5472a146de967bd.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 5f20b2e679037af4b18ac901bdf78a08e5c0da39.
Diffstat (limited to 'src/part/radialMap/widget.cpp')
-rw-r--r--src/part/radialMap/widget.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/part/radialMap/widget.cpp b/src/part/radialMap/widget.cpp
index e1b606f..fd8ff14 100644
--- a/src/part/radialMap/widget.cpp
+++ b/src/part/radialMap/widget.cpp
@@ -46,11 +46,11 @@ RadialMap::Widget::url( File const * const file ) const
}
void
-RadialMap::Widget::invalidate( const bool b )
+RadialMap::Widget::tqinvalidate( const bool b )
{
if( isValid() )
{
//**** have to check that only way to invalidate is this function frankly
//**** otherwise you may get bugs..
//disable mouse tracking
@@ -65,7 +65,7 @@ RadialMap::Widget::invalidate( const bool b )
//FIXME move this disablement thing no?
// it is confusing in other areas, like the whole createFromCache() thing
- m_map.invalidate( b ); //b signifies whether the pixmap is made to look disabled or not
+ m_map.tqinvalidate( b ); //b signifies whether the pixmap is made to look disabled or not
if( b )
update();
@@ -77,10 +77,10 @@ RadialMap::Widget::invalidate( const bool b )
void
RadialMap::Widget::create( const Directory *tree )
{
//it is not the responsibility of create() to invalidate first
//skip invalidation at your own risk
//FIXME make it the responsibility of create to invalidate first
if( tree )
{
@@ -102,8 +102,8 @@ RadialMap::Widget::create( const Directory *tree )
void
RadialMap::Widget::createFromCache( const Directory *tree )
{
- //no scan was necessary, use cached tree, however we MUST still emit invalidate
- invalidate( false );
+ //no scan was necessary, use cached tree, however we MUST still emit tqinvalidate
+ tqinvalidate( false );
create( tree );
}
@@ -46,11 +46,11 @@ RadialMap::Widget::url( File const * const file ) const
if( isValid() )
{
- //**** have to check that only way to invalidate is this function frankly
+ //**** have to check that only way to tqinvalidate is this function frankly
//**** otherwise you may get bugs..
//disable mouse tracking
@@ -77,10 +77,10 @@ RadialMap::Widget::invalidate( const bool b )
RadialMap::Widget::create( const Directory *tree )
{
- //it is not the responsibility of create() to invalidate first
+ //it is not the responsibility of create() to tqinvalidate first
//skip invalidation at your own risk
@@ -77,10 +77,10 @@ RadialMap::Widget::invalidate( const bool b )
//skip invalidation at your own risk
- //FIXME make it the responsibility of create to invalidate first
+ //FIXME make it the responsibility of create to tqinvalidate first
if( tree )
{